runif_panel_design returns a data.frame object with
nseq rows. Each row corresponds to a parameter set drawn randomly
from a multivariate uniform distribution specified by the lower,
upper, specific_names and unit_names arguments.
Arguments
lower, upper
named numeric vectors giving the lower and upper bounds
of the ranges, respectively.
nseq
Total number of points requested
specific_names
Character vector containing the names of unit-specific
parameters. This argument must be used in conjunction with the argument
unit_names; it is used if the search bounds for all unspecified
unit-specific parameters are the same.
unit_names
Character vector containing the names of the units of the
panel. If not used in conjunction with unit_names this argument
is ignored.