Learn R Programming

panelPomp (version 1.7.0.0)

panelGompertz: Panel Gompertz model

Description

Builds a collection of independent realizations from the Gompertz model.

Usage

panelGompertz(
  N = 100,
  U = 50,
  params = c(K = 1, r = 0.1, sigma = 0.1, tau = 0.1, X.0 = 1),
  seed = 12345678
)

Value

A panelPomp object.

Arguments

N

number of observations for each unit.

U

number of units.

params

parameter vector, assuming all units have the same parameters.

seed

passed to the random number generator for simulation.

Author

Edward L. Ionides, Carles Bretó

References

Bretó, C., Ionides, E. L. and King, A. A. (2020) Panel Data Analysis via Mechanistic Models. Journal of the American Statistical Association, 115(531), 1178--1188. tools:::Rd_expr_doi("https://doi.org/10.1080/01621459.2019.1604367")

King, A. A., Nguyen, D. and Ionides, E. L. (2016) Statistical inference for partially observed Markov processes via the package pomp. Journal of Statistical Software 69(12), 1--43. DOI: 10.18637/jss.v069.i12. An updated version of this paper is available on the package website.

See Also

Other panelPomp examples: contacts(), panelMeasles(), panelRandomWalk()

Examples

Run this code
panelGompertz()

Run the code above in your browser using DataLab