Learn R Programming

panelPomp (version 1.7.0.0)

panelGompertzLikelihood: Likelihood for a panel Gompertz model via a Kalman filter

Description

Evaluates the likelihood function for a panel Gompertz model, using a format convenient for maximization by optim() to obtain a maximum likelihood estimate. Specifically, estimated and fixed parameters are supplied by two different arguments.

Usage

panelGompertzLikelihood(x, panelPompObject, params)

Value

A numeric value.

Arguments

x

named vector for a subset of parameters, corresponding to those being estimated.

panelPompObject

a panel Gompertz model.

params

named vector containing all the parameters of the panel Gompertz model. Estimated parameters are overwritten by x.

Author

Edward L. Ionides

Examples

Run this code
pg <- panelGompertz(N=2,U=2)
panelGompertzLikelihood(coef(pg),pg,coef(pg))

Run the code above in your browser using DataLab