panelGompertzLikelihood: Likelihood for a panel Gompertz model via a Kalman filter
Description
Evaluates the likelihood function for a panel Gompertz model,
using a format convenient for maximization by optim() to obtain a maximum
likelihood estimate. Specifically, estimated and fixed parameters are
supplied by two different arguments.